@@ -1,10 +1,7 @@
-# pylint: disable=invalid-name
 """ __init__ module. """
 import re
 
-# noinspection PyUnresolvedReferences
-# pylint: disable=import-error
-from .syspath_utils import (  # noqa
+from .syspath_utils import (
     add_srcdirs_to_syspath,
     filtered_sorted_syspath,
     get_package_and_max_relative_import_dots,
@@ -12,8 +9,6 @@ from .syspath_utils import (  # noqa
     print_syspath,
 )
 
-# pylint: enable=import-error
-
-__version__ = "0.1.13"
+__version__ = "0.1.20"
 
 init_std_syspath_filter(re.compile(r"([Jj]et[Bb]rains|[Pp]ython|PyCharm|v\w*env)"))
